Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(120)

Unified Diff: chrome/browser/sync/glue/data_type_error_handler.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/data_type_error_handler.h
diff --git a/chrome/browser/sync/glue/data_type_error_handler.h b/chrome/browser/sync/glue/data_type_error_handler.h
index bea93f7c9ee724dec2021d9700f768a454c0b5b5..962a85b9f8f440193c78e7f36a8e0d87b0a1adba 100644
--- a/chrome/browser/sync/glue/data_type_error_handler.h
+++ b/chrome/browser/sync/glue/data_type_error_handler.h
@@ -23,10 +23,10 @@ class DataTypeErrorHandler {
const tracked_objects::Location& from_here,
const std::string& message) = 0;
// This will create a SyncError object. This will also upload
// a breakpad call stack to crash server. A sync error usually means
// that sync has to be disabled either for that type or completely.
- virtual SyncError CreateAndUploadError(
+ virtual csync::SyncError CreateAndUploadError(
const tracked_objects::Location& location,
const std::string& message,
syncable::ModelType type) = 0;
@@ -23,10 +23,10 @@ class DataTypeErrorHandler {
const tracked_objects::Location& from_here,
const std::string& message) = 0;
- // This will create a SyncError object. This will also upload
+ // This will create a csync::SyncError object. This will also upload
// a breakpad call stack to crash server. A sync error usually means
// that sync has to be disabled either for that type or completely.
« no previous file with comments | « chrome/browser/sync/glue/data_type_controller_mock.h ('k') | chrome/browser/sync/glue/data_type_error_handler_mock.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698